from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '0.1.12'
DESCRIPTION = 'eazyml genai'
LONG_DESCRIPTION = 'eazyml genai with linux and windows compatibility'

# Setting up
setup(
    name="eazyml-genai",
    version=VERSION,
    author="Eazyml",
    author_email="admin@ipsoftlabs.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    package_dir={"eazyml_genai":"./eazyml_genai"},
    package_data={'' : ['*.py', '*.so', '*.dylib', '*.pyd']},
    install_requires=['accelerate==0.30.1',
                        'altair==5.3.0',
                        'anyio== 3.7.1',
                        'attrs==23.2.0',
                        'bcrypt==4.1.2',
                        'blinker==1.8.2',
                        'blis==0.7.11',
                        'Brotli==1.0.9',
                        'cachetools==5.3.3',
                        'catalogue==2.0.10',
                        'certifi==2024.2.2',
                        'charset-normalizer==2.0.4',
                        'click==8.1.7',
                        'cymem==2.0.8',
                        'distro==1.9.0',
                        'elastic-transport==8.13.0',
                        'elasticsearch==8.11.0',
                        'et-xmlfile==1.1.0',
                        'exceptiongroup==1.2.0',
                        'filelock==3.14.0',
                        'fsspec==2024.5.0',
                        'gitdb==4.0.11',
                        'GitPython==3.1.43',
                        'h11==0.14.0',
                        'httpcore==1.0.5',
                        'httpx==0.27.0',
                        'huggingface-hub==0.23.0',
                        'idna==3.6',
                        'importlib-metadata==6.11.0',
                        'itsdangerous==2.1.2',
                        'Jinja2==3.1.3',
                        'joblib==1.3.2',
                        'jsonschema==4.21.1',
                        'jsonschema-specifications==2023.12.1',
                        'langcodes==3.3.0',
                        'markdown-it-py==3.0.0',
                        'MarkupSafe==2.1.3',
                        'mdurl==0.1.2',
                        'mkl-fft==1.3.8',
                        'mkl-random==1.2.4',
                        'mkl-service==2.4.0',
                        'mpmath==1.3.0',
                        'murmurhash==1.0.10',
                        'networkx==3.3',
                        'nltk==3.8.1',
                        'numpy==1.26.4',
                        'nvidia-cublas-cu12==12.1.3.1',
                        'nvidia-cuda-cupti-cu12==12.1.105',
                        'nvidia-cuda-nvrtc-cu12==12.1.105',
                        'nvidia-cuda-runtime-cu12==12.1.105',
                        'nvidia-cudnn-cu12==8.9.2.26',
                        'nvidia-cufft-cu12==11.0.2.54',
                        'nvidia-curand-cu12==10.3.2.106',
                        'nvidia-cusolver-cu12==11.4.5.107',
                        'nvidia-cusparse-cu12==12.1.0.106',
                        'nvidia-nccl-cu12==2.20.5',
                        'nvidia-nvjitlink-cu12==12.4.127',
                        'nvidia-nvtx-cu12==12.1.105',
                        'openai==1.3.6',
                        'openpyxl==3.1.2',
                        'packaging==23.2',
                        'pandas==2.0.3',
                        'pathlib_abc==0.1.1',
                        'pathy==0.11.0',
                        'Pillow==9.5.0',
                        'pip==23.3.1',
                        'preshed==3.0.9',
                        'protobuf==4.25.3',
                        'psutil==5.9.8',
                        'pyarrow==15.0.2',
                        'pydantic==1.9.0',
                        'pydeck==0.8.1b0',
                        'Pygments==2.17.2',
                        'PyJWT==2.8.0',
                        'PyMuPDF==1.24.0',
                        'PyMuPDFb==1.24.0',
                        'PySocks==1.7.1',
                        'python-dateutil==2.9.0.post0',
                        'pyttsx3==2.90',
                        'pytz==2024.1',
                        'PyYAML==6.0.1',
                        'referencing==0.34.0',
                        'regex==2023.12.25',
                        'requests==2.31.0',
                        'rich==13.7.1',
                        'rpds-py==0.18.0',
                        'safetensors==0.4.3',
                        'scikit-learn==1.3.2',
                        'scipy==1.13.0',
                        'setuptools==68.2.2',
                        'six==1.16.0',
                        'smart-open==6.4.0',
                        'smmap==5.0.1',
                        'sniffio==1.3.1',
                        'spacy',
                        'spacy-legacy==3.0.12',
                        'spacy-loggers==1.0.5',
                        'srsly==2.4.8',
                        'sympy==1.12',
                        'tenacity==8.2.3',
                        'thinc',
                        'threadpoolctl==3.4.0',
                        'tiktoken==0.6.0',
                        'timeout-decorator==0.5.0',
                        'tokenizers==0.19.1',
                        'toml==0.10.2',
                        'toolz==0.12.1',
                        'tornado==6.4',
                        'tqdm==4.66.2',
                        'transformers==4.41.0',
                        'triton==2.3.0',
                        'typer==0.4.2',
                        'typing_extensions==4.10.0',
                        'tzdata==2024.1',
                        'tzlocal==5.2',
                        'Unidecode==1.3.8',
                        'urllib3==2.2.1',
                        'validators==0.33.0',
                        'wasabi==0.10.1',
                        'watchdog==4.0.0',
                        'Werkzeug==3.0.2',
                        'wheel==0.41.2',
                        'zipp==3.17.0',
                        'Flask==3.0.3'
                      ],
    keywords=['python'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
   ] 
)
